# Generated by Django 2.0 on 2018-01-10 15:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('raiseapp', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='reward',
            name='timeframe',
            field=models.TextField(blank=True),
        ),
    ]
